@@ -16,7 +16,7 @@ use DBI;
 use Exception::Class::DBI;
 
 
-our $VERSION = '0.01';
+our $VERSION = '0.093';
 
 AxKit::App::TABOO::Data::Plurals::Categories->dbtable("categories");
 AxKit::App::TABOO::Data::Plurals::Categories->dbfrom("categories");
@@ -34,7 +34,7 @@ Often, you want to retrieve many different categories from the data store, for e
 
 =over
 
-=item C<new()>
+=item C<new(@dbconnectargs)>
 
 The constructor. Nothing special.
 
@@ -45,32 +45,50 @@ sub new {
     my $class = ref($that) || $that;
     my $self = {
 	ENTRIES => [], # Internally, some methods finds it useful that the entries are stored in a array of this name.
-	XMLELEMENT => 'categories',
-	XMLNS => 'http://www.kjetil.kjernsmo.net/software/TABOO/NS/Category/Output',
+	DBCONNECTARGS => \@_,
+	XMLPREFIX => undef,
+	XMLELEMENT => undef,
+	XMLNS => undef,
     };
     bless($self, $class);
     return $self;
 }
 
 
-=item C<load(what => fields, limit => {key => value, [...]})>
+=item C<load(what =E<gt> fields, limit =E<gt> {key =E<gt> value, [...]}, orderby =E<gt> fields, entries =E<gt> number)>
 
-It takes a hashref where the keys are data storage names and the values are corresponding values to retrieve. These will be combined by logical AND. It will retrieve the data, and then call C<populate()> for each of the records retrieved to ensure that the plural data objects actually consists of an array of L<AxKit::App::TABOO::Data::Category>s. But it calls the internal C<_load()>-method to do the hard work (and that's in the parent class).
+This load method can be used to retrieve a number of entries from a
+data store.  It uses named parameters, the first C<what> is used to
+determine which fields to retrieve. It is a string consisting of a
+commaseparated list of fields, as specified in the data store. The
+C<limit> argument is to be used to determine which records to
+retrieve, these will be combined by logical AND. You may also supply a
+C<orderby> argument, which is an expression used to determine the
+order of entries returned. Finally, you may supply a C<entries>
+argument, which is the maximum number of entries to retrieve.
+
+It will retrieve the data, and then call C<populate()> for each of the
+records retrieved to ensure that the plural data objects actually
+consists of an array of L<AxKit::App::TABOO::Data::Category>s. But it
+calls the internal C<_load()>-method to do the hard work (and that's
+in the parent class).
+
+If there is no data that corresponds to the given arguments, this
+method will return C<undef>.
 
 =cut
 
 
 sub load {
   my ($self, %args) = @_;
-  my @cats;
   my $data = $self->_load(%args); # Does the hard work
+  return undef unless (@{$data});
   foreach my $entry (@{$data}) {
-    my $cat = AxKit::App::TABOO::Data::Category->new();
+    my $cat = AxKit::App::TABOO::Data::Category->new($self->dbconnectargs());
     $cat->populate($entry);
     $cat->onfile;
-    push(@cats, $cat);
+    $self->Push($cat);
   }
-  ${$self}{ENTRIES} = \@cats;
   return $self;
 }
 
@@ -78,6 +96,8 @@ sub load {
 
 =head1 BUGS/TODO
 
+Not anything particular at the moment...
+
 
 =head1 FORMALITIES
 
